/* ***************************************************************** */
/* (c) Copyright Rocket Software, Inc. 2019,2024 All Rights Reserved */
/* ***************************************************************** */
/*  Licensed Materials - Property of IBM                             */
/*  Product(s):                                                      */
/*     5698-012 IBM Z OMEGAMON AI for JVM                            */
/*                                                                   */
/*  (C)Copyright IBM Corporation 2016                                */
/*                                                                   */
/*  US Government Users Restricted Rights - Use, duplication or      */
/*  disclosure restricted by GSA ADP Schedule Contract with          */
/*  IBM Corp.                                                        */
/* ***************************************************************** */
/*                                                                   */
/*  Maintenance Log:                                                 */
/*                                                                   */
/*  Date     Who   ID  Description                                   */
/*  -------- ---- ---  -----------------------------------------     */
/*  12/08/15 KRM       Initial Development for KJJ situations        */
/*  03/15/16 mjr       Warning situations should not overlap the     */
/*                     the Critical situations for the same metric.  */
/*                     Defect 52391, APAR OA50242, PTF UA81330       */
/*  07/28/16 JPY       Added Situation for z/OS Connect Request sum  */
/*  12/20/18 FF        Added Situations for z/OS Connect SPE (v5404) */
/*  01/11/18 FF        Deleted QIBCLASSID column in all situations   */
/*                       to resolve Error: Failed to resolve object  */
/*                       name for EIB notification                   */
/*  10/22/19 smw       Added new situations for v550                 */
/*  08/04/21 uuy       Added new situations for v5505                */
/*  08/30/22 uuy       Added new Action commands for JVM utilities   */  
/*  06/16/23 uuy       Added new situations for v6100                */ 
/*  04/04/24 uuy       Added new situations for v6101                */    
/*                                                                   */
/*                                                                   */
/* ***************************************************************** */
/*                                                                   */
/*  Insert situations for JVM Monitor                                */
/*                                                                   */
/* ***************************************************************** */

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_General_CPU_Critical",                            /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=CPU.JVMPID;SEV=Critical~",                       /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if general CPU percent is more than 75",  /* TEXT */
   "*IF *VALUE JVM_CPU.General_CPU_Percent *GT 75.00"         /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_General_CPU_Warning",                             /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=CPU.JVMPID;SEV=Warning~",                        /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if general CPU percent is more than 50",   /* TEXT */
   "*IF *VALUE JVM_CPU.General_CPU_Percent *GT 50.00 *AND *VALUE
    JVM_CPU.General_CPU_Percent *LE 75.00"                    /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_GC_Pause_Critical",                               /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Critical~",                    /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if percent time in GC Pause is more than 5", /*TXT*/
   "*IF *VALUE JVM_Garbage_Collection.Percent_Time_in_Collection_Pauses
*GT 5.00"                                                     /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_GC_Pause_Warning",                                /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Warning~",                     /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if percent time in GC Pause is more than 2", /*TEXT*/
   "*IF *VALUE JVM_Garbage_Collection.Percent_Time_in_Collection_Pauses
    *GT 2.00 *AND *VALUE
     JVM_Garbage_Collection.Percent_Time_in_Collection_Pauses *LE 5.00
   "                                                          /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_IFA_on_General_CPU_Critical",                     /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=CPU.JVMPID;SEV=Critical~",                       /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if IFA on general CPU percent is more than 50", 
   "*IF *VALUE JVM_CPU.IFA_on_General_CPU_Percent *GT 50.00"  /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_IFA_on_General_CPU_Warning",                      /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=CPU.JVMPID;SEV=Warning~",                        /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if IFA on general CPU percent is more than 25", 
   "*IF *VALUE JVM_CPU.IFA_on_General_CPU_Percent *GT 25.00 *AND *VALUE
     JVM_CPU.IFA_on_General_CPU_Percent *LE 50.00"            /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_Lock_Missed_Critical",                            /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=LOCKS.JVMPID;SEV=Critical~",                     /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if lock missed percent is more than 50",  /* TEXT */
   "*IF *VALUE JVM_Locks.Missed_Percent *GT 50.00"            /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_Lock_Missed_Warning",                             /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=LOCKS.JVMPID;SEV=Warning~",                      /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if lock missed percent is more than 10",   /* TEXT */
   "*IF *VALUE JVM_Locks.Missed_Percent *GT 10.00 *AND *VALUE
    JVM_Locks.Missed_Percent *LE 50.00"                       /* PDT */
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_Occupancy_after_GC_Critical",                     /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Critical~",                    /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if the average occupancy percent is more than 80",
   "*IF *VALUE JVM_Garbage_Collection.Avg_Occupancy_Percent *GT 80.00"
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_System_GC_Warning",                               /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Warning~",                     /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if any system GC occurred during interval",
   "*IF *VALUE JVM_Garbage_Collection.System_Collection_Count *GE 1"
 );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_Thread_Blocked_Warning",                          /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000000000000000",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V530",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=THREADS.JVMPID;SEV=Warning~",                    /* SITINFO */
   "",                                                     /* SOURCE */
   "Warning alert if any thread is in blocked status",       /* TEXT */
   "*IF *VALUE JVM_Threads.State *EQ BLOCKED"                 /* PDT */
 );
 
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_zOS_Connect_Http_Warning",                        /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        000000000L00000000",       /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1181213124702000",                                    /* LSTDATE */
   "V5404",                                            /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "001500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=ZCDETL.JVMPID;SEV=Warning~",                     /* SITINFO */ 
   "",                                                     /* SOURCE */
   "A request occurred with an HTTP Error",                  /* TEXT */
   "*IF *VALUE JVM_zOSConnect_Details.HTTP_Code *GT 299" 
 ); 
  
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_zOS_Connect_Resp_Critical",                      /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000L00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1181217223946000",                                   /* LSTDATE */
   "V5404",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCDETL.JVMPID;SEV=Critical~",                   /* SITINFO */ 
   "",                                                    /* SOURCE */
   "z/OS Connect Request Response Time is Critical",        /* TEXT */
   "*IF *VALUE JVM_zOSConnect_Details.Total_Request_Time 
   *GT 3.000000"
 ); 
 
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_zOS_Connect_Resp_Warning",                       /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000L00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1181217224036000",                                   /* LSTDATE */
   "V5404",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCDETL.JVMPID;SEV=Warning~",                    /* SITINFO */ 
   "",                                                    /* SOURCE */
   "z/OS Connect Request Response Time is high",            /* TEXT */
   "*IF *VALUE JVM_zOSConnect_Details.Total_Request_Time 
   *GT 1.000000 *AND *VALUE
    JVM_zOSConnect_Details.Total_Request_Time *LE 3.000000" 
 );
 
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_zOS_Connect_Timeout_Warning",                    /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000L00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1181217224057000",                                   /* LSTDATE */
   "V5404",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCDETL.JVMPID;SEV=Warning~",                    /* SITINFO */ 
   "",                                                    /* SOURCE */
   "A z/OS Connect request timed out",                      /* TEXT */
   "*IF *VALUE JVM_zOSConnect_Details.Timeout *EQ Y" 
 ); 
 
/* ***************************************************************** */
/*                                                                   */
/*  Insert situations for v550                                       */
/*                                                                   */
/* ***************************************************************** */
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM64Free_Warning",                              /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021224057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Warning~",                    /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The warning threshold for free 64-bit memory has been breached",
   "*IF *VALUE JVM_Virtual_Memory.Mem64_Free_Pct *GT 10 *AND *VALUE 
    JVM_Virtual_Memory.Mem64_Free_Pct *LE 20"                /* PDT */   
 ); 


INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM64Free_Critical",                             /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021224057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Critical~",                   /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The critical threshold for free 64-bit memory has been breached",  
   "*IF *VALUE JVM_Virtual_Memory.Mem64_Free_Pct *LT 10"    /*  pdt */  
 ); 


INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM31Free_Warning",                              /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021231057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Warning~",                    /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The warning threshold for free 31-bit memory has been breached",
   "*IF *VALUE JVM_Virtual_Memory.Mem31_Free_Pct *GT 10 *AND *VALUE 
    JVM_Virtual_Memory.Mem31_Free_Pct *LE 20"                /* PDT */     
 ); 

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM31Free_Critical",                             /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021231057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Critical~",                   /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The critical threshold for free 31-bit memory has been breached",
   "*IF *VALUE JVM_Virtual_Memory.Mem31_Free_Pct *LT 10"     /* PDT */  
 ); 


INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM24Free_Warning",                              /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021224057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Warning~",                    /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The warning threshold for free 24-bit memory has been breached", 
   "*IF *VALUE JVM_Virtual_Memory.Mem24_Free_Pct *GT 10 *AND *VALUE 
    JVM_Virtual_Memory.Mem24_Free_Pct *LE 20"                /* PDT */   
 ); 

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_MEM24Free_Critical",                             /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000y00000000",      /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1191021224057000",                                   /* LSTDATE */
   "V5500",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZOSMEM.JVMPID;SEV=Critical~",                   /* SITINFO */ 
   "",                                                    /* SOURCE */
   "The critical threshold for free 24-bit memory has been breached",
   "*IF *VALUE JVM_Virtual_Memory.Mem24_Free_Pct *LT 10"     /* PDT */ 
 ); 


/* ***************************************************************** */
/*                                                                   */
/*  Insert situations for v5505                                      */
/*                                                                   */
/* ***************************************************************** */
   
   
 
INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_API_Req_Http_Warning",                           /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000z000HyQ0a7",     /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1210426042057000",                                   /* LSTDATE */
   "V5505",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCOUBDET.JVMPID;SEV=Warning~",                  /* SITINFO */ 
   "",                                                    /* SOURCE */
   "Endpoint HTTP error",
   "*IF *VALUE JVM_zOSConnect_APIRequester_Detail.Endpoint_HTTP_Code 
   *GE 299"                                                  /* PDT */ 
 ); 

 INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_API_Req_Resp_Time_Warning",                      /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000z000HyQ0a7",     /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1210426042057000",                                   /* LSTDATE */
   "V5505",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCOUBDET.JVMPID;SEV=Warning~",                  /* SITINFO */ 
   "",                                                    /* SOURCE */
   "Requester API with high response time",
   "*IF *VALUE JVM_zOSConnect_APIRequester_Detail.Request_Process_Time
   *GT 1.000000 *AND *VALUE 
   JVM_zOSConnect_APIRequester_Detail.Request_Process_Time 
   *LE 3.000000"                                            /* PDT */
 );
 
 INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_API_Req_Resp_Time_Critical",                     /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                 /*  ADVICE */
   "%IBM.JVM_Monitor        000000000z000HyQ0a7",     /* AFFINITIES */
   "",                                                 /* ALERTLIST */
   "NNN",                                               /* AUTOSOPT */
   "*NO",                                              /* AUTOSTART */
   "*NONE",                                                  /* CMD */
   "",                                                  /* DESTNODE */
   "",                                                 /* EVENTATTR */
   "",                                                       /* HUB */
   "",                                                   /* LOCFLAG */
   "en_US",                                             /* LSTCCSID */
   "1210426042057000",                                   /* LSTDATE */
   "V5505",                                           /* LSTRELEASE */
   "SYSADMIN",                                         /* LSTUSRPRF */
   "",                                                     /* NOCOL */
   "",                                               /* NOITIFYARGS */
   "",                                               /* NOITIFYOPTS */
   "",                                                /* OBJECTLOCK */
   "",                                                   /* PRNAMES */
   "E",                                                 /* QIBSCOPE */
   "0",                                                /* REEV_DAYS */
   "001500",                                           /* REEV_TIME */
   "",                                                  /* REFLEXOK */
   "",                                                  /* RESERVED */
   "*NONE",                                             /* SENDMSGQ */
   "ATOM=ZCOUBDET.JVMPID;SEV=Warning~",                  /* SITINFO */ 
   "",                                                    /* SOURCE */
   "Requester API with high response time",
   "*IF *VALUE JVM_zOSConnect_APIRequester_Detail.Request_Process_Time 
   *GE 3.000000"                                              /* PDT */ 
 );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("%IBM.JVM_Monitor        000000000z000HyQ0a7" ,     /* AFFINITIES */
   "JJ:&JVM_Health_Summary.Job_Name &JVM_Health_Summary.ASID 
&JVM_Health_Summary.JVMPID SVCDUMP" ,                         /* CMD */
   "Request a system (SVC) dump." ,                          /* DESC */
   " " ,                                                     /* ICON */
   "JJCMD001" ,                                               /* KEY */
   "SVC Dump" ,                                              /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("%IBM.JVM_Monitor        000000000z000HyQ0a7" ,     /* AFFINITIES */
   "JJ:&JVM_Health_Summary.Job_Name &JVM_Health_Summary.ASID 
&JVM_Health_Summary.JVMPID JAVACORE" ,                         /*CMD */
   "Request a Java Core Dump." ,                             /* DESC */
   " " ,                                                     /* ICON */
   "JJCMD002" ,                                               /* KEY */
   "Javacore" ,                                              /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.CCT
  (AFFINITIES ,
   CMD ,
   DESC ,
   ICON ,
   KEY ,
   NAME ,
   RESERVED ,
   SECURITY ,
   TABLES ,
   VERSION
  )
VALUES
  ("%IBM.JVM_Monitor        000000000z000HyQ0a7" ,     /* AFFINITIES */
   "JJ:&JVM_Health_Summary.Job_Name &JVM_Health_Summary.ASID 
&JVM_Health_Summary.JVMPID HEAPDUMP" ,                         /*CMD */
   "Request a Java Heap Dump." ,                             /* DESC */
   " " ,                                                     /* ICON */
   "JJCMD003" ,                                               /* KEY */
   "Heap Dump" ,                                             /* NAME */
   " " ,                                                 /* RESERVED */
   " " ,                                                 /* SECURITY */
   " " ,                                                   /* TABLES */
   " "                                                    /* VERSION */
  );

INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_Occ_After_Gbl_GC_Critical",                       /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000016000HyQ0a7",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V610",                                             /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Critical~",                    /* SITINFO */
   "",                                                     /* SOURCE */
   "Critical alert if occupancy % after Global GC is more than 90",
   "*IF *VALUE JVM_Garbage_Collection.Heap_Occ_Pct_After_Global 
   *GT 90.00"                                                /* PDT */
 );

  INSERT INTO O4SRV.TSITDESC
  (SITNAME,
   ADVISE,
   AFFINITIES,
   ALERTLIST,
   AUTOSOPT,
   AUTOSTART,
   CMD,
   DESTNODE,
   EVENTATTR,
   HUB,
   LOCFLAG,
   LSTCCSID,
   LSTDATE,
   LSTRELEASE,
   LSTUSRPRF,
   NOCOL,
   NOTIFYARGS,
   NOTIFYOPTS,
   OBJECTLOCK,
   PRNAMES,
   QIBSCOPE,
   REEV_DAYS,
   REEV_TIME,
   REFLEXOK,
   RESERVED,
   SENDMSGQ,
   SITINFO,
   SOURCE,
   TEXT,
   PDT
 )
 VALUES (
   "JVM_GC_Thread_Count_Warning",                         /* SITNAME */
   'ADVICE("kjj:"+$ISITSTSH.SITNAME$);',                  /*  ADVICE */
   "%IBM.JVM_Monitor        0000000017000nyQ0a7",      /* AFFINITIES */
   "",                                                  /* ALERTLIST */
   "NNN",                                                /* AUTOSOPT */
   "*NO",                                               /* AUTOSTART */
   "*NONE",                                                   /* CMD */
   "",                                                   /* DESTNODE */
   "",                                                  /* EVENTATTR */
   "",                                                        /* HUB */
   "",                                                    /* LOCFLAG */
   "en_US",                                              /* LSTCCSID */
   "1151208115751000",                                    /* LSTDATE */
   "V6101",                                            /* LSTRELEASE */
   "SYSADMIN",                                          /* LSTUSRPRF */
   "",                                                      /* NOCOL */
   "",                                                /* NOITIFYARGS */
   "",                                                /* NOITIFYOPTS */
   "",                                                 /* OBJECTLOCK */
   "",                                                    /* PRNAMES */
   "E",                                                  /* QIBSCOPE */
   "0",                                                 /* REEV_DAYS */
   "000500",                                            /* REEV_TIME */
   "",                                                   /* REFLEXOK */
   "",                                                   /* RESERVED */
   "*NONE",                                              /* SENDMSGQ */
   "ATOM=GCSUMM.JVMPID;SEV=Warning~",                     /* SITINFO */
   "",                                                     /* SOURCE */
   "GC Thread Count Warning",
   "*IF *VALUE JVM_Garbage_Collection.Last_GC_Thread_Count 
   *GT JVM_CPU.Logical_zIIP_Cores"                            /* PDT */
 );

/* ***************************************************************** */
/*  These Update statements were added for the LP purposes           */
/* ***************************************************************** */
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123783"
    WHERE SITNAME = "JVM_API_Req_Http_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123784"
    WHERE SITNAME = "JVM_API_Req_Resp_Time_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123785"
    WHERE SITNAME = "JVM_API_Req_Resp_Time_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123786"
    WHERE SITNAME = "JVM_GC_Pause_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123787"
    WHERE SITNAME = "JVM_GC_Pause_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123788"
    WHERE SITNAME = "JVM_General_CPU_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123789"
    WHERE SITNAME = "JVM_General_CPU_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123790"
    WHERE SITNAME = "JVM_IFA_on_General_CPU_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123791"
    WHERE SITNAME = "JVM_IFA_on_General_CPU_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123792"
    WHERE SITNAME = "JVM_Lock_Missed_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123793"
    WHERE SITNAME = "JVM_Lock_Missed_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123794"
    WHERE SITNAME = "JVM_MEM24Free_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123795"
    WHERE SITNAME = "JVM_MEM24Free_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123796"
    WHERE SITNAME = "JVM_MEM31Free_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123797"
    WHERE SITNAME = "JVM_MEM31Free_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123798"
    WHERE SITNAME = "JVM_MEM64Free_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123799"
    WHERE SITNAME = "JVM_MEM64Free_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123800"
    WHERE SITNAME = "JVM_Occupancy_after_GC_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123801"
    WHERE SITNAME = "JVM_System_GC_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123802"
    WHERE SITNAME = "JVM_Thread_Blocked_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123803"
    WHERE SITNAME = "JVM_zOS_Connect_Http_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123804"
    WHERE SITNAME = "JVM_zOS_Connect_Resp_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123805"
    WHERE SITNAME = "JVM_zOS_Connect_Resp_Warning";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ2022318735123806"
    WHERE SITNAME = "JVM_zOS_Connect_Timeout_Warning";
UPDATE O4SRV.TSITDESC
SET ADVISE = 'ADVICE("kjj:"+$ISITSTSH.SITNAME$);'
WHERE SITNAME = "TEMS_Alert";
UPDATE O4SRV.CCT
    SET DESC = "Kjj:KJJ2022318735123807"
    WHERE NAME = "SVC Dump";
UPDATE O4SRV.CCT
    SET DESC = "Kjj:KJJ2022318735123808"
    WHERE NAME = "Javacore";
UPDATE O4SRV.CCT
    SET DESC = "Kjj:KJJ2022318735123809"
    WHERE NAME = "Heap Dump";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ202320575441171"
    WHERE SITNAME = "JVM_Occ_After_Gbl_GC_Critical";
*******************************************************************************
*                        FP1 LP Preparation Process                           *
*******************************************************************************
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ202320575441171"
    WHERE SITNAME = "JVM_Occ_After_Gbl_GC_Critical";
UPDATE O4SRV.TSITDESC
    SET TEXT = "Kjj:KJJ202413024921959"
    WHERE SITNAME = "JVM_GC_Thread_Count_Warning";
